Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon SNS.

Actions, resources, and condition keys for Amazon SNS - Service Authorization Reference

# Actions, resources, and condition keys for Amazon SNS

Amazon SNS (service prefix: `sns` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon SNS
- Resource types defined by Amazon SNS
- Condition keys for Amazon SNS

## Actions defined by Amazon SNS

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddPermission | Grants permission to add a statement to a topic's access control policy, granting access for the specified AWS accounts to the specified actions | Permissions management | topic* |  |
CheckIfPhoneNumberIsOptedOut | Grants permission to accept a phone number and indicate whether the phone holder has opted out of receiving SMS messages from your account | Read |  |  |
ConfirmSubscription | Grants permission to verify an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier Subscribe action | Write | topic* |  |
CreatePlatformApplication | Grants permission to create a platform application object for one of the supported push notification services, such as APNS and GCM, to which devices and mobile apps may register | Write |  |  | iam:PassRole
CreatePlatformEndpoint | Grants permission to create an endpoint for a device and mobile app on one of the supported push notification services, such as GCM and APNS | Write |  |  |
CreateSMSSandboxPhoneNumber | Grants permission to add a destination phone number and send a one-time password (OTP) to that phone number for an AWS account | Write |  |  |
CreateTopic | Grants permission to create a topic to which notifications can be published | Write | topic* |  | iam:PassRole
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteEndpoint | Grants permission to delete the endpoint for a device and mobile app from Amazon SNS | Write |  |  |
DeletePlatformApplication | Grants permission to delete a platform application object for one of the supported push notification services, such as APNS and GCM | Write |  |  |
DeleteSMSSandboxPhoneNumber | Grants permission to delete an AWS account's verified or pending phone number | Write |  |  |
DeleteTopic | Grants permission to delete a topic and all its subscriptions | Write | topic* |  |
GetEndpointAttributes | Grants permission to retrieve the endpoint attributes for a device on one of the supported push notification services, such as GCM and APNS | Read |  |  |
GetPlatformApplicationAttributes | Grants permission to retrieve the attributes of the platform application object for the supported push notification services, such as APNS and GCM | Read |  |  |
GetSMSAttributes | Grants permission to return the settings for sending SMS messages from your account | Read |  |  |
GetSMSSandboxAccountStatus | Grants permission to retrieve the sandbox status for the calling account in the target region | Read |  |  |
GetSubscriptionAttributes | Grants permission to return all of the properties of a subscription | Read |  |  |
GetTopicAttributes | Grants permission to return all of the properties of a topic | Read | topic* |  |
ListEndpointsByPlatformApplication | Grants permission to list the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM and APNS | List |  |  |
ListOriginationNumbers | Grants permission to list all origination numbers, and their metadata | List |  |  |
ListPhoneNumbersOptedOut | Grants permission to return a list of phone numbers that are opted out, meaning you cannot send SMS messages to them | Read |  |  |
ListPlatformApplications | Grants permission to list the platform application objects for the supported push notification services, such as APNS and GCM | List |  |  |
ListSMSSandboxPhoneNumbers | Grants permission to list the calling account's current pending and verified destination phone numbers | List |  |  |
ListSubscriptions | Grants permission to return a list of the requester's subscriptions | List |  |  |
ListSubscriptionsByTopic | Grants permission to return a list of the subscriptions to a specific topic | List | topic* |  |
ListTagsForResource | Grants permission to list all tags added to the specified Amazon SNS topic | Read | topic |  |
ListTopics | Grants permission to return a list of the requester's topics | List |  |  |
OptInPhoneNumber | Grants permission to opt in a phone number that is currently opted out, which enables you to resume sending SMS messages to the number | Write |  |  |
Publish | Grants permission to send a message to all of a topic's subscribed endpoints | Write | topic* |  |
RemovePermission | Grants permission to remove a statement from a topic's access control policy | Permissions management | topic* |  |
SetEndpointAttributes | Grants permission to set the attributes for an endpoint for a device on one of the supported push notification services, such as GCM and APNS | Write |  |  |
SetPlatformApplicationAttributes | Grants permission to set the attributes of the platform application object for the supported push notification services, such as APNS and GCM | Write |  |  | iam:PassRole
SetSMSAttributes | Grants permission to set the default settings for sending SMS messages and receiving daily SMS usage reports | Write |  |  |
SetSubscriptionAttributes | Grants permission to allow a subscription owner to set an attribute of the topic to a new value | Write |  |  |
SetTopicAttributes | Grants permission to allow a topic owner to set an attribute of the topic to a new value | Write | topic* |  | iam:PassRole
Subscribe | Grants permission to prepare to subscribe an endpoint by sending the endpoint a confirmation message | Write | topic* |  |
| sns:Endpoint sns:Protocol |
TagResource | Grants permission to add tags to the specified Amazon SNS topic | Tagging | topic |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
Unsubscribe | Grants permission to delete a subscription | Write |  |  |
UntagResource | Grants permission to remove tags from the specified Amazon SNS topic | Tagging | topic |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
VerifySMSSandboxPhoneNumber | Grants permission to verify a destination phone number with a one-time password (OTP) for an AWS account | Write |  |  |

## Resource types defined by Amazon SNS

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
topic | `arn:$ { Partition}:sns:$ { Region}:$ { Account}:$ { TopicName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon SNS

Amazon SNS defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tags from request | String
aws:ResourceTag/${TagKey} | Filters access by tags associated with the restource | String
aws:TagKeys | Filters access by tag keys from request | ArrayOfString
sns:Endpoint | Filters access by the URL, email address, or ARN from a Subscribe request or a previously confirmed subscription | String
sns:Protocol | Filters access by the protocol value from a Subscribe request or a previously confirmed subscription | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.